@@ -1,6 +1,6 @@
 """Top-level package for nhdpy."""
 
-__author__ = """Joseph Stachelek"""
+__author__ = """Jemma Stachelek"""
 __email__ = 'stachel2@msu.edu'
 __version__ = '0.1.0'
 
